SentenceFormatter

Enum SentenceFormatter 

pub enum SentenceFormatter {
Show 18 variants Dp, Dtm, Gbs, Gga, Gll, Gns, Grs, Gsa, Gst, Gsv, Hdt, Llq, Mss, Rmc, Rot, Txt, Vtg, Zda,
}
Variants



Dp

Dynamic positioning.



Dtm

Datum reference information.



Gbs

GNSS satellite fault detection (RAIM support).



Gga

Time, position, and fix related data.



Gll

Position data: position fix, time of position fix, and status.



Gns

GNS Fix data.



Grs

GRS range residuals.



Gsa

GPS DOP and active satellites.



Gst

Position error statistics.



Gsv

Number of SVs in view, PRN, elevation, azimuth, and SNR.



Hdt

Heading from True North.



Llq

Leica local position and quality.



Mss

MSK receiver signal.



Rmc

Position, Velocity, and Time.



Rot

Rate of turn.



Txt

Text transmission.



Vtg

Actual track made good and speed over ground.



Zda

UTC day, month, and year, and local time zone offset.