Gst

Struct Gst 

pub struct Gst {
    pub device: Option<String>,
    pub time: Option<DateTime<Utc>>,
    pub rms: Option<f32>,
    pub major: Option<f32>,
    pub minor: Option<f32>,
    pub orientation: Option<f32>,
    pub alt: Option<f32>,
    pub lat: Option<f32>,
    pub lon: Option<f32>,
    pub v_east: Option<f32>,
    pub v_north: Option<f32>,
    pub v_up: Option<f32>,
}
GST - GPS Pseudorange Noise Statistics

Fields

device: Option<String>

Name of originating device

time: Option<DateTime<Utc>>

Time/date stamp in ISO8601 format, UTC. May have a fractional part of up to .001sec precision.

rms: Option<f32>

Value of the standard deviation of the range inputs to the navigation process (range inputs include pseudoranges and DGPS corrections).

major: Option<f32>

Standard deviation of semi-major axis of error ellipse, in meters.

minor: Option<f32>

Standard deviation of semi-minor axis of error ellipse, in meters.

orientation: Option<f32>

Orientation of semi-major axis of error ellipse, in degrees from true north.

alt: Option<f32>

Standard deviation of altitude error, in meters.

lat: Option<f32>

Standard deviation of latitude error, in meters.

lon: Option<f32>

Standard deviation of longitude error, in meters.

v_east: Option<f32>

Standard deviation of East velocity error, in meters / second.

v_north: Option<f32>

Standard deviation of North velocity error, in meters / second.

v_up: Option<f32>

Standard deviation of Up velocity error, in meters / second.