SkyView

Struct SkyView 

pub struct SkyView {
Show 15 fields pub device: Option<String>, pub geometric_dop: Option<f32>, pub horizontal_dop: Option<f32>, pub position_dop: Option<f32>, pub time_dop: Option<f32>, pub vertical_dop: Option<f32>, pub x_dop: Option<f32>, pub y_dop: Option<f32>, pub satellites: Vec<Satellite>, pub time: Option<DateTime<Utc>>, pub number_of_satellites: Option<u32>, pub pr: Option<f32>, pub pr_rate: Option<f32>, pub pr_res: Option<f32>, pub qual: Option<u8>,
}
Sky view of the GPS satellite positions.

Fields

device: Option<String>

Name of the originating device.

geometric_dop: Option<f32>

Geometric (hyperspherical) dilution of precision, a combination of PDOP and TDOP.

A dimensionless factor which should be multiplied by a base UERE to get an error estimate.

horizontal_dop: Option<f32>

Horizontal dilution of precision, a dimensionless factor which should be multiplied by a base UERE to get a circular error estimate.

position_dop: Option<f32>

Position (spherical/3D) dilution of precision, a dimensionless factor which should be multiplied by a base UERE to get an error estimate.

time_dop: Option<f32>

Time dilution of precision, a dimensionless factor which should be multiplied by a base UERE to get an error estimate.

vertical_dop: Option<f32>

Vertical (altitude) dilution of precision, a dimensionless factor which should be multiplied by a base UERE to get an error estimate.

x_dop: Option<f32>

Longitudinal dilution of precision, a dimensionless factor which should be multiplied by a base UERE to get an error estimate. A.k.a. Northing DOP.

y_dop: Option<f32>

Latitudinal dilution of precision, a dimensionless factor which should be multiplied by a base UERE to get an error estimate. A.k.a. Easting DOP.

satellites: Vec<Satellite>

List of satellite objects in skyview

time: Option<DateTime<Utc>>

Time/date stamp in ISO8601 format, UTC.

May have a fractional part of up to .001sec precision.

number_of_satellites: Option<u32>

Number of satellites used in navigation solution.

pr: Option<f32>

Pseudorange, in meters.

pr_rate: Option<f32>

Pseudorange Rate of Change, in meters / second.

pr_res: Option<f32>

Pseudorange residue, in meters.

qual: Option<u8>

Quality Indicator.

  • 0 = no signal
  • 1 = searching signal
  • 2 = signal acquired
  • 3 = signal detected but unusable
  • 4 = code locked and time synchronized
  • 5, 6, 7 = code and carrier locked and time synchronized