Struct Device
pub struct Device {Show 15 fields
pub activated: Option<DateTime<Utc>>,
pub bps: Option<u32>,
pub cycle: Option<Duration>,
pub min_cycle: Option<Duration>,
pub driver: Option<String>,
pub flags: DeviceFlags,
pub hex_data: Option<String>,
pub native: Option<u8>,
pub parity: Option<String>,
pub path: Option<String>,
pub readonly: bool,
pub serial_number: Option<String>,
pub stopbits: Option<u8>,
pub subtype: Option<String>,
pub subtype1: Option<String>,
}Expand description
Device object.
Fields
activated: Option<DateTime<Utc>>Time the device was activated as an ISO8601 time stamp.
If the device is inactive this attribute is absent.
bps: Option<u32>Device speed in bits per second.
cycle: Option<Duration>Device cycle time in seconds.
min_cycle: Option<Duration>Device minimum cycle time in seconds.
Reported from ?DEVICE when (and only when) the rate is switchable. It is read-only and not settable.
driver: Option<String>GPSD’s name for the device driver type.
Won’t be reported before gpsd has seen identifiable packets from the device.
flags: DeviceFlagsBit vector of property flags.
Currently defined flags are: describe packet types seen so far (GPS, RTCM2, RTCM3, AIS). Won’t be reported if empty, e.g. before gpsd has seen identifiable packets from the device.
hex_data: Option<String>Data, in bare hexadecimal, to send to the GNSS receiver.
native: Option<u8>0 means NMEA mode and 1 means alternate mode (binary if it has one, for SiRF and Evermore chipsets in particular).
Attempting to set this mode on a non-GPS device will yield an error.
parity: Option<String>N, O or E for no parity, odd, or even.
path: Option<String>Name the device for which the control bits are being reported, or for which they are to be applied.
This attribute may be omitted only when there is exactly one subscribed channel.
readonly: boolTrue if device is read-only.
serial_number: Option<String>Hardware serial number (if the device driver returns that value).
stopbits: Option<u8>Stop bits (1 or 2).
subtype: Option<String>Whatever version information the device driver returned.
subtype1: Option<String>More version information the device driver returned.